
IS_ARTICLE_TYPE_ENABLED = False
IS_ARTICLE_HITCOUNT_ENABLED = False
ARE_COMMENTS_ENABLED = False
ARE_TAGS_ENABLED = False
